@@ -1,5 +1,5 @@
 fem_main <-
-function(Y,K,init,maxit,eps,Tinit,model,kernel,method,graph,Hess,memlim,nbcore){
+function(Y,K,init,maxit,eps,Tinit,model,kernel,method,graph,Hess){
 
   # Initialization
   Y = as.matrix(Y)
@@ -38,8 +38,7 @@ function(Y,K,init,maxit,eps,Tinit,model,kernel,method,graph,Hess,memlim,nbcore){
              'GS'= fstep.GramSc(Y,T,kernel),
              'REG'  = fstep.qiao(Y,T,kernel))
   prms      = mstep(Y,V,T,model=model,method=method)
-  if ((n < memlim) || (nbcore==1)) res.estep = estep(prms,Y,V)
-  else res.estep = estep_par(prms,Y,V,memlim,nbcore)
+  res.estep = estep(prms,Y,V)
   T         = res.estep$T
   Lobs[1]   = res.estep$loglik
   
@@ -54,8 +53,7 @@ function(Y,K,init,maxit,eps,Tinit,model,kernel,method,graph,Hess,memlim,nbcore){
                'GS'= fstep.GramSc(Y,T,kernel),
                'REG'  = fstep.qiao(Y,T,kernel))
     prms      = mstep(Y,V,T,model=model,method=method)
-    if ((n < memlim) || (nbcore==1)) res.estep = estep(prms,Y,V)
-    else res.estep = estep_par(prms,Y,V,memlim,nbcore)
+    res.estep = estep(prms,Y,V)
     T         = res.estep$T
     Lobs[i+1] = res.estep$loglik
     
